<?php

/**
 * ClearLIFE class.
 *
 * @category   apps
 * @package    clearlife
 * @subpackage libraries
 * @author     ClearFoundation <developer@clearfoundation.com>
 * @copyright  2003-2021 ClearFoundation
 * @license    http://www.gnu.org/copyleft/lgpl.html GNU Lesser General Public License version 3 or later
 * @link       http://www.clearfoundation.com/docs/developer/apps/clearlife/
 */

///////////////////////////////////////////////////////////////////////////////
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
///////////////////////////////////////////////////////////////////////////////


namespace clearos\apps\clearlife;

///////////////////////////////////////////////////////////////////////////////
// B O O T S T R A P
///////////////////////////////////////////////////////////////////////////////

$bootstrap = getenv('CLEAROS_BOOTSTRAP') ? getenv('CLEAROS_BOOTSTRAP') : '/usr/clearos/framework/shared';
require_once $bootstrap . '/bootstrap.php';

///////////////////////////////////////////////////////////////////////////////
// T R A N S L A T I O N S
///////////////////////////////////////////////////////////////////////////////

clearos_load_language('clearlife');

///////////////////////////////////////////////////////////////////////////////
// D E P E N D E N C I E S
///////////////////////////////////////////////////////////////////////////////

// Classes
//--------

use \clearos\apps\base\Daemon as Daemon;
use \clearos\apps\base\Engine as Engine;
use \clearos\apps\base\Engine_Exception as Engine_Exception;

clearos_load_library('base/Daemon');
clearos_load_library('base/Engine');
clearos_load_library('base/Shell');

// Exceptions
//-----------

use \clearos\apps\base\Shell as Shell;
use \Exception as Exception;

clearos_load_library('base/Engine_Exception');

///////////////////////////////////////////////////////////////////////////////
// C L A S S
///////////////////////////////////////////////////////////////////////////////

/**
 * ClearLIFE class.
 *
 * @category   apps
 * @package    clearlife
 * @subpackage libraries
 * @author     ClearFoundation <developer@clearfoundation.com>
 * @copyright  2006-2021 ClearFoundation
 * @license    http://www.gnu.org/copyleft/lgpl.html GNU Lesser General Public License version 3 or later
 * @link       http://www.clearfoundation.com/docs/developer/apps/clearlife/
 */

class Clearlife extends Daemon
{
    ///////////////////////////////////////////////////////////////////////////////
    // C O N S T A N T S
    ///////////////////////////////////////////////////////////////////////////////

    const COMMAND_CURL = '/usr/bin/curl';
    const COMMAND_KILL = '/bin/kill';
    const SERVER_PATH = 'http://localhost:25433';
    const URL_GET_QR_CODE = 'http://localhost:25433/getqr';
    const URL_NODE_SYNC_STATUS = 'http://localhost:25433/nodesync';
    const URL_GET_APP_LIST = 'http://localhost:25433/listapps';
    const URL_GET_STATUS = 'http://localhost:25433/status';

    ///////////////////////////////////////////////////////////////////////////////
    // M E T H O D S
    ///////////////////////////////////////////////////////////////////////////////

    /**
     * ClearLIFE constructor.
     */

    public function __construct()
    {
        clearos_profile(__METHOD__, __LINE__);
    }

    ///////////////////////////////////////////////////////////////////////////////
    // P U B L I C  M E T H O D S
    ///////////////////////////////////////////////////////////////////////////////

    /**
     * Get QR Code.
     *
     * @return string QR CODE
     * @throws Engine_Exception
     */


    public function get_qr_code()
    {
        clearos_profile(__METHOD__, __LINE__);

        $shell = new Shell();

        try {
            $shell->execute(self::COMMAND_CURL, self::URL_GET_QR_CODE);

            $output = $shell->get_output();

            if (isset($output) && isset($output[3])) {

                $data = json_decode($output[3]);
                $image = $data->image;
                return $image;
            }
        } catch (Exception $e) {
            throw new Engine_Exception(lang("clearlife_app_api_catch_error"));
        }
    }

    /**
     * Get Node SYNC status.
     *
     * @return boolean success
     * @throws Engine_Exception
     */

    public function get_node_sync_status()
    {

        clearos_profile(__METHOD__, __LINE__);
        $shell = new Shell();

        try {

            $shell->execute(self::COMMAND_CURL, self::URL_NODE_SYNC_STATUS);
            $output = $shell->get_output();

            if (isset($output) && isset($output[3])) {
                $data = json_decode($output[3]);
                $success = $data->success;
                return $success;
            }
        } catch (Exception $e) {
            throw new Engine_Exception(lang("clearlife_app_api_catch_error"));
        }
    }

    /**
     * Get Status.
     *
     * @return array status
     * @throws Engine_Exception
     */

    public function get_status()
    {
        clearos_profile(__METHOD__, __LINE__);
        
        $shell = new Shell();

        try {

            $shell->execute(self::COMMAND_CURL, self::URL_GET_STATUS);

            $output = $shell->get_output();

            if (isset($output) && isset($output[3])) {
                $data = json_decode($output[3]);
                return $data;
            }
        } catch (Exception $e) {
            throw new Engine_Exception((lang("clearlife_app_api_catch_error")));
        }
    }

    /**
     * Get Connected applications.
     *
     * @return array application list
     * @throws Engine_Exception
     */

    public function get_applications()
    {
        clearos_profile(__METHOD__, __LINE__);
        
        $shell = new Shell();

        try {

            $shell->execute(self::COMMAND_CURL, self::URL_GET_APP_LIST);

            $output = $shell->get_output();

            if (isset($output) && isset($output[3])) {
                $data = json_decode($output[3]);
                return $data;
            }
        } catch (Exception $e) {
            throw new Engine_Exception((lang("clearlife_app_api_catch_error")));
        }
    }

    ///////////////////////////////////////////////////////////////////////////////
    // P R I V A T E  M E T H O D S
    ///////////////////////////////////////////////////////////////////////////////
}
